@@ -17,17 +17,27 @@
 
 import decorator
 from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_policy import opts
 from oslo_policy import policy
 from oslo_utils import importutils
 import pecan
 
 from magnum.common import clients
 from magnum.common import exception
+from magnum.common import policies
 
 
+LOG = logging.getLogger(__name__)
 _ENFORCER = None
 CONF = cfg.CONF
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
 
 # we can get a policy enforcer by this init.
 # oslo policy support change policy rule dynamically.
@@ -60,6 +70,8 @@ def init(policy_file=None, rules=None,
                                     default_rule=default_rule,
                                     use_conf=use_conf,
                                     overwrite=overwrite)
+        _ENFORCER.register_defaults(policies.list_rules())
+
     return _ENFORCER
 
 
@@ -95,8 +107,14 @@ def enforce(context, rule=None, target=None,
         target = {'project_id': context.project_id,
                   'user_id': context.user_id}
     add_policy_attributes(target)
-    return enforcer.enforce(rule, target, credentials,
-                            do_raise=do_raise, exc=exc, *args, **kwargs)
+
+    try:
+        result = enforcer.enforce(rule, target, credentials,
+                                  do_raise=do_raise, exc=exc, *args, **kwargs)
+    except policy.InvalidScope as ex:
+        LOG.debug(f"Invalid scope while enforce policy :{str(ex)}")
+        raise exc(action=rule)
+    return result
 
 
 def add_policy_attributes(target):
