@@ -52,8 +52,9 @@ class ClusterStatus(fields.Enum):
 class ClusterHealthStatus(fields.Enum):
     HEALTHY = 'HEALTHY'
     UNHEALTHY = 'UNHEALTHY'
+    UNKNOWN = 'UNKNOWN'
 
-    ALL = (HEALTHY, UNHEALTHY)
+    ALL = (HEALTHY, UNHEALTHY, UNKNOWN)
 
     STATUS_FAILED = (UNHEALTHY)
 
@@ -98,9 +99,9 @@ class ContainerStatus(fields.Enum):
 
 class ClusterType(fields.Enum):
     ALL = (
-        KUBERNETES, SWARM, MESOS, DCOS, SWARM_MODE,
+        KUBERNETES, SWARM, SWARM_MODE,
     ) = (
-        'kubernetes', 'swarm', 'mesos', 'dcos', 'swarm-mode',
+        'kubernetes', 'swarm', 'swarm-mode',
     )
 
     def __init__(self):
